@@ -1,7 +1,7 @@
-package Bencher::Scenarios::GetoptLong;
+package Bencher::Scenarios::GetoptLongEvenLess;
 
 our $DATE = '2016-01-08'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -18,11 +18,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenarios::GetoptLong - Bencher scenarios to benchmark Getopt::Long
+Bencher::Scenarios::GetoptLongEvenLess - Bencher scenarios to benchmark Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.01 of Bencher::Scenarios::GetoptLong (from Perl distribution Bencher-Scenarios-GetoptLongEvenLess), released on 2016-01-08.
+This document describes version 0.02 of Bencher::Scenarios::GetoptLongEvenLess (from Perl distribution Bencher-Scenarios-GetoptLongEvenLess), released on 2016-01-08.
 
 =head1 SEE ALSO
 
